import { HttpParams } from "@angular/common/http";
import { LambertModel, LocationModel } from "../types/location.model";
import { AddressQueryModel } from "../types/address-query.model";
import { AddressModel, LatLngModel } from "../types/address.model";
import { CoordinateModel } from "../types/coordinate.model";
import * as i0 from "@angular/core";
export declare class NgxLocationPickerHelper {
    /**
     * NgxLocationPickerHelper constructor
     */
    constructor();
    minX: number;
    maxX: number;
    minY: number;
    maxY: number;
    /**
     * Converts a query object to HttpParams.
     *
     * @param query (the object containing a set of parameters)
     *
     * @return HttpParams
     */
    toHttpParams(query: any): HttpParams;
    /**
     * Converts a query object to a query string
     *
     * @param obj (the object containing a set of parameters)
     *
     * @return any
     */
    private queryObjectToStringObject;
    /**
     * Normalize search value
     *
     * @return string
     */
    normalizeSearchValue(value: string): string;
    /**
     * Determines if the given query input resembles an address or not.
     *
     * @return boolean
     */
    isAddress(query: string, locationKeywords: string[]): boolean;
    /**
     * Determines if the given query input resembles coordinate pairs
     *
     * @return boolean
     */
    isCoordinate(query: string): boolean;
    /**
     * Determines if the given object matches LocationModel interface
     *
     *
     */
    isLocationModel(object: any): object is LocationModel;
    /**
     * Determines if the given query input resembles alternative coordinate pairs ex: 51,205729 4,388629
     *
     * @return boolean
     */
    isAlternativeCoordinateNotation(query: string): boolean;
    convertAlternativeCoordinateToNormalNotation(query: string): string;
    /**
     * Splits the location query in street name and house number and checks for streetnameid.
     *
     * @return streetAndNumber
     */
    buildAddressQuery(query: string, selectedLocation: LocationModel | AddressModel | CoordinateModel, onlyAntwerp: boolean, countryCodes: string[], buffer?: number, coordinateSearch?: LatLngModel, streetIds?: number[]): AddressQueryModel;
    /**
     * Splits the location query in X/Y coordinate.
     *
     * @return coordinate
     */
    extractXYCoord(query: string): LambertModel;
    /**
     * Checks wether given coordinates are WGS84 (response true) or Lambert (response false)
     *
     * @param x given x coordinate
     * @param y given y coordinate
     *
     * @return isWgs84
     */
    isWgs84Coordinates(x?: number, y?: number): boolean;
    /**
     * Converts lambertcoordinates to wgs84 coordinate
     *
     * @param lambertCoordinate lambertmodel coordinates
     *
     * @return wgs84coordinates
     */
    convertLambertToWgs84Coordinates(lambertCoordinate: LambertModel): LambertModel;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxLocationPickerHelper, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NgxLocationPickerHelper>;
}
