import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { NgxLocationPickerHelper } from './ngx-location-picker.helper';
import { LocationModel } from '../types/location.model';
import { AddressModel } from '../types/address.model';
import { CoordinateModel } from '../types/coordinate.model';
import { DelegateSearchModel } from '../types/delegate-search.model';
import * as i0 from "@angular/core";
export declare class NgxLocationPickerService {
    private httpClient;
    private locationPickerHelper;
    private locationPickerApi;
    /**
     * NgxLocationPickerService constructor
     *
     * @param httpClient (httpClient used for making requests to the api)
     * @param locationPickerHelper (Helper functions class)
     */
    constructor(httpClient: HttpClient, locationPickerHelper: NgxLocationPickerHelper);
    /**
     * Main search function. Determines which action to undertake based on the provided search string.
     *
     * @param delegateSearch (the delegateSearch model)
     *
     * @return Observable<LocationModel[] | AddressModel[] | CoordinateModel[]>
     */
    delegateSearch(delegateSearch: DelegateSearchModel): Observable<LocationModel[] | AddressModel[] | CoordinateModel[]>;
    /**
     * Returns a list of layers present in elastic.
     *
     * @return Observable<LayerModel[]>
     */
    getLayers(): Observable<string[]>;
    /**
     * Search locations by user input
     *
     * @param query (the location to look for)
     *
     * @return Observable<LocationModel[]>
     */
    private searchLocations;
    /**
     * Search addresses based on street name and house number
     *
     * @param query (the address to look for, consists of a street name and house number)
     *
     * @return Observable<AddressModel[]>
     */
    private searchAddresses;
    /**
     * Get an address by id
     *
     * @param query (the address id to get)
     *
     * @return Observable<AddressModel[]>
     */
    private searchAddressById;
    /**
     * Search locations based on a set of coordinates
     *
     * @param query (search query containing coordinates and other parameters)
     *
     * @return Observable<CoordinateModel[]>
     */
    private searchLocationsByCoordinates;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxLocationPickerService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NgxLocationPickerService>;
}
